/* How to reproduce tables in "Gender Norm Conflict and Market Outcomes" */

* set your directory * 
cd ""
use ACS_GSS_marketdata.dta, clear

gen employed_m= employed if sex==1
gen employed_f= employed if sex==2
bysort rce_state_deg_chrt: egen employed_M=max(employed_m)
bysort rce_state_deg_chrt: egen employed_F=max(employed_f)
drop employed_m employed_f
gen emp_diff=employed_M-employed_F

gen woman_modern=1-TRAD_GRP_F
gen product_disagreement = TRAD_GRP_M*woman_modern
gen product_dis_skill= product_disagreement*bac
gen woman_more_mod= woman_modern> TRAD_GRP_M
gen product_dis_bywmm = TRAD_GRP_M*woman_modern* woman_more_mod

label var product_disagreement "Conflict: (F-Mod share) x (M-Trad share)"
label var product_dis_skill "Conflict: (F-Mod share) x (M-Trad share) x Skilled"
label var woman_modern "Share: F-Modern"
label var TRAD_GRP_M "Share: M-Traditional"
label var product_dis_bywmm "Conflict: (F-Mod share) x (M-Trad share) x 1(F-Mod share>M-Trad share)"
label var ever_married "Ever Married"
label var cur_divorce "Currently Divorced"
label var has_child "Has Child in Household"

*** summary statistics *** 
fsum ever_married cur_divorce TRAD_GRP_M  if sex==1 &  count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
fsum ever_married cur_divorce TRAD_GRP_F  if sex==2 &  count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24

fsum ever_married cur_divorce TRAD_GRP_M  if sex==1&bac==0  &  count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
fsum ever_married cur_divorce TRAD_GRP_F  if sex==2&bac==0 &  count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24

fsum ever_married cur_divorce TRAD_GRP_M  if sex==1&bac==1  &  count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
fsum ever_married cur_divorce TRAD_GRP_F  if sex==2&bac==1 &  count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24

fsum ever_married cur_divorce TRAD_GRP_M  if sex==1&race==1  &  count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
fsum ever_married cur_divorce TRAD_GRP_F  if sex==2&race==1  &  count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24

fsum ever_married cur_divorce TRAD_GRP_M if sex==1&race==2  &  count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
fsum ever_married cur_divorce TRAD_GRP_F  if sex==2&race==2  &  count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24

** summary statistics for distribution of gender norm conflic variable ** 
sum product_disagreement if count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, detail

tab race if product_disagreement> .2853742 &count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
tab region_big if product_disagreement> .2853742 &count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
tab cohort_bin if product_disagreement> .2853742 &count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
tab bac if product_disagreement> .2853742 &count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24

tab race if product_disagreement<= .2853742 &count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
tab region_big if product_disagreement<= .2853742 &count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
tab cohort_bin if product_disagreement<= .2853742 &count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
tab bac if product_disagreement<= .2853742 &count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24

************** RESULTS ************ 
** both race ** 
reg ever_married product_disagreement  woman_modern TRAD_GRP_M  i.cohort_bin  i.market_stateFE if sex==1  & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes replace
reg ever_married product_disagreement  woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE if sex==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append
reg cur_divorce product_disagreement  woman_modern TRAD_GRP_M  i.cohort_bin  i.market_stateFE if sex==1 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append
reg cur_divorce product_disagreement  woman_modern TRAD_GRP_M  i.cohort_bin  i.market_stateFE if sex==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append

** by employment difference ** 
reg ever_married product_disagreement  woman_modern TRAD_GRP_M  i.cohort_bin  i.market_stateFE emp_diff if sex==1  & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_empld.xls, keep(product_disagreement woman_modern TRAD_GRP_M emp_diff) nocons label  nonotes replace
reg ever_married product_disagreement  woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE emp_diff  if sex==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_empld.xls, keep(product_disagreement woman_modern TRAD_GRP_M emp_diff) nocons label  nonotes append
reg cur_divorce product_disagreement  woman_modern TRAD_GRP_M  i.cohort_bin  i.market_stateFE emp_diff  if sex==1 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_empld.xls, keep(product_disagreement woman_modern TRAD_GRP_M emp_diff) nocons label  nonotes append
reg cur_divorce product_disagreement  woman_modern TRAD_GRP_M  i.cohort_bin  i.market_stateFE emp_diff  if sex==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_empld.xls, keep(product_disagreement woman_modern TRAD_GRP_M emp_diff) nocons label  nonotes append

** by skill ** 
reg ever_married product_disagreement product_dis_skill woman_modern TRAD_GRP_M     i.cohort_bin  i.market_stateFE if sex==1 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_byskill.xls, keep(product_disagreement product_dis_skill woman_modern TRAD_GRP_M) nocons label  nonotes replace
reg ever_married product_disagreement product_dis_skill  woman_modern TRAD_GRP_M     i.cohort_bin  i.market_stateFE if sex==2  & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_byskill.xls, keep(product_disagreement product_dis_skill woman_modern TRAD_GRP_M) nocons label  nonotes append
reg cur_divorce product_disagreement product_dis_skill  woman_modern TRAD_GRP_M    i.cohort_bin  i.market_stateFE if sex==1  & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_byskill.xls, keep(product_disagreement product_dis_skill woman_modern TRAD_GRP_M) nocons label  nonotes append
reg cur_divorce product_disagreement product_dis_skill  woman_modern TRAD_GRP_M    i.cohort_bin  i.market_stateFE if sex==2  & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_byskill.xls, keep(product_disagreement product_dis_skill woman_modern TRAD_GRP_M) nocons label  nonotes append

** by heterogeneity in gender norm conflict ** 
reg ever_married product_disagreement product_dis_bywmm woman_modern TRAD_GRP_M   i.cohort_bin  i.market_stateFE if sex==1  & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_bywmm.xls, keep(product_disagreement product_dis_bywmm woman_modern TRAD_GRP_M) nocons label  nonotes replace
reg ever_married product_disagreement product_dis_bywmm woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE if sex==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_bywmm.xls, keep(product_disagreement product_dis_bywmm woman_modern TRAD_GRP_M) nocons label  nonotes append
reg cur_divorce product_disagreement product_dis_bywmm woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE if sex==1 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_bywmm.xls, keep(product_disagreement product_dis_bywmm woman_modern TRAD_GRP_M) nocons label  nonotes append
reg cur_divorce product_disagreement product_dis_bywmm woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE if sex==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_bywmm.xls, keep(product_disagreement product_dis_bywmm woman_modern TRAD_GRP_M) nocons label  nonotes append

************ APPENDIX TABLES ************** 
** drop gender norm level terms ** 
reg ever_married product_disagreement  i.cohort_bin  i.market_stateFE if sex==1  & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_nolevel.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes replace
reg ever_married product_disagreement  i.cohort_bin  i.market_stateFE if sex==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_nolevel.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append
reg cur_divorce product_disagreement   i.cohort_bin  i.market_stateFE if sex==1 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_nolevel.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append
reg cur_divorce product_disagreement   i.cohort_bin  i.market_stateFE if sex==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using maintable_nolevel.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append

**by race** 
reg ever_married product_disagreement woman_modern TRAD_GRP_M   i.cohort_bin  i.market_stateFE if sex==1&race==1 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using marriage_byrace.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes replace
reg ever_married product_disagreement woman_modern TRAD_GRP_M   i.cohort_bin  i.market_stateFE if sex==1&race==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using marriage_byrace.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append
reg ever_married product_disagreement woman_modern TRAD_GRP_M   i.cohort_bin  i.market_stateFE if sex==2&race==1 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using marriage_byrace.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append
reg ever_married product_disagreement woman_modern TRAD_GRP_M  i.cohort_bin  i.market_stateFE if sex==2&race==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using marriage_byrace.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append

reg cur_divorce product_disagreement woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE if sex==1&race==1 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using divorce_byrace.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes replace
reg cur_divorce product_disagreement woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE if sex==1&race==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using divorce_byrace.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append
reg cur_divorce product_disagreement woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE if sex==2&race==1 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using divorce_byrace.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append
reg cur_divorce product_disagreement woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE if sex==2&race==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using divorce_byrace.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append

** has children ** 
reg has_child product_disagreement woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE if sex==1 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using haschild_table.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes replace
reg has_child product_disagreement woman_modern TRAD_GRP_M i.cohort_bin  i.market_stateFE if sex==2 & count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24, cl(state)
outreg2 using haschild_table.xls, keep(product_disagreement woman_modern TRAD_GRP_M) nocons label  nonotes append


***GRAPHS ** 

bysort cohort_bin: egen mean_WM_trad=mean(TRAD_GRP_M) if race==1& count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
bysort cohort_bin: egen mean_WF_trad=mean(TRAD_GRP_F) if race==1& count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
bysort cohort_bin: egen mean_BM_trad=mean(TRAD_GRP_M) if race==2& count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
bysort cohort_bin: egen mean_BF_trad=mean(TRAD_GRP_F) if race==2& count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24

bysort cohort_bin: egen mean_WM_mar=mean(ever_married) if race==1&sex==1& count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
bysort cohort_bin: egen mean_WF_mar=mean(ever_married) if race==1&sex==2& count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
bysort cohort_bin: egen mean_BM_mar=mean(ever_married) if race==2&sex==1& count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24
bysort cohort_bin: egen mean_BF_mar=mean(ever_married) if race==2&sex==2& count_TRD_M >24 & count_TRD_F >24 &count_div_M>24& count_div_F>24

label var mean_WM_trad  "White Male"
label var mean_WF_trad  "White Female"
label var mean_BM_trad  "Black Male"
label var mean_BF_trad  "Black Female"

label var mean_WM_mar "White Male"
label var mean_WF_mar "White Female"
label var mean_BM_mar "Black Male"
label var mean_BF_mar "Black Female"

label var cohort_bin "Birth Year"

label define cohort_bins 1 "1920-29" 2 "1930-39" 3 "1940-49" 4 "1950-59" 5 "1960-69" 6 "1970-79" 
label values cohort_bin cohort_bins

twoway (connected  mean_WM_mar cohort_bin, m(circle) mc(black) lc(black) lw(thick) ) (connected  mean_WF_mar cohort_bin, m(triangle) mc(black) lc(black) lw(med) ) (connected  mean_BM_mar cohort_bin, m(circle) mc(black) lp(dash) lc(black) lw(thick) ) (connected  mean_BF_mar cohort_bin, m(triangle) mc(black) lp(dash) lc(black) lw(med)), title(Share married by sex and race) xlabel(, valuelabel labsize(small)) 
graph export married_race_sex.png, replace
twoway (connected  mean_WM_trad cohort_bin, m(circle) mc(black) lc(black) lw(thick) ) (connected  mean_WF_trad cohort_bin, m(triangle) mc(black) lc(black) lw(med) ) (connected  mean_BM_trad cohort_bin, m(circle) mc(black) lp(dash) lc(black) lw(thick) ) (connected  mean_BF_trad cohort_bin, m(triangle) mc(black) lp(dash) lc(black) lw(med)), title(Share traditional by sex and race) xlabel(, valuelabel labsize(small))
graph export traditional_race_sex.png, replace
