/* How to create ACS merged with GSS data at the market-cohort level */

* set your directory * 
cd ""
use ACS.dta, clear
keep perwt empstat nchild marst race sex statefip bpl stateicp region age birthyr educd sex age year 
gen has_child= nchild>0 if !mi(nchild)
gen ever_married=marst<6
gen cur_divorced=marst==4 if ever_married==1
gen bac=educd>81
gen employed=empstat==1 if empstat<3
gen state=stateicp
keep if race<3
keep if age>29&age<81
gen cohort_bin=.
forval i=0/5{
replace cohort_bin=`=`i'+1' if birthyr>`=1919+`=`i'*10''&birthyr<`=1930+`=`i'*10''
}
keep if cohort_bin!=.
gen region_big=. 
replace region_big=1 if region<13
replace region_big=2 if region>12&region<23
replace region_big=3 if region>22&region<34
replace region_big=4 if region>34

tostring race state region_big bac sex cohort_bin, force replace
gen rce_rgnbig_deg_sx_chrt=race + region_big + bac + sex + cohort_bin
gen rce_state_deg_sx_chrt=race + state + bac + sex + cohort_bin
gen rce_state_deg_chrt=race + state + bac  + cohort_bin
destring race state region_big bac sex cohort_bin rce_rgnbig_deg_sx_chrt rce_state_deg_sx_chrt rce_state_deg_chrt, replace 

* count variable constructed for ever-married individuals only (so the markets being pulled from do not vary for ever-married or cur-div analysis) * 
bysort rce_state_deg_sx_chrt: egen count=count(cur_divorced)
gen count_m=count if sex==1
gen count_f=count if sex==2
bysort rce_state_deg_chrt: egen count_div_M=max(count_m)
bysort rce_state_deg_chrt: egen count_div_F=max(count_f)
replace count_div_M=0 if mi(count_div_M)
replace count_div_F=0 if mi(count_div_F)

* merge with GSS market data * 
merge m:1 rce_rgnbig_deg_sx_chrt using GSS_marketdata.dta
keep if _merge==3
tostring race region_big state bac sex, replace 
gen market_stateFE=race + state + bac + sex

destring race region_big state bac sex market_stateFE, replace
collapse tradition TRAD_GRP_M TRAD_GRP_F count_TRD_M count_TRD_F employed has_child ever_married cur_divorced race bac sex cohort_bin region_big state rce_state_deg_chrt count_div_M count_div_F market_stateFE [pw=perwt],  by(rce_state_deg_sx_chrt)

save ACS_GSS_marketdata.dta, replace
